@@ -6,7 +6,7 @@
  * @package PhpMyAdmin
  */
 
-use PMA\libraries\Response;
+use PhpMyAdmin\Response;
 require_once 'libraries/common.inc.php';
 
 if ($GLOBALS['cfg']['EnableAutocompleteForTablesAndColumns']) {
