@@ -5,13 +5,19 @@
  *
  * @package PhpMyAdmin
  */
-use PMA\libraries\Response;
-use PMA\libraries\Encoding;
-use PMA\libraries\plugins\ImportPlugin;
-use PMA\libraries\File;
-use PMA\libraries\URL;
-use PMA\libraries\Util;
-use PMA\libraries\Bookmark;
+
+use PhpMyAdmin\Bookmark;
+use PhpMyAdmin\Core;
+use PhpMyAdmin\Encoding;
+use PhpMyAdmin\File;
+use PhpMyAdmin\Import;
+use PhpMyAdmin\ParseAnalyze;
+use PhpMyAdmin\Plugins;
+use PhpMyAdmin\Plugins\ImportPlugin;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Sql;
+use PhpMyAdmin\Url;
+use PhpMyAdmin\Util;
 
 /* Enable LOAD DATA LOCAL INFILE for LDI plugin */
 if (isset($_POST['format']) && $_POST['format'] == 'ldi') {
@@ -22,28 +28,25 @@ if (isset($_POST['format']) && $_POST['format'] == 'ldi') {
  * Get the variables sent or posted to this script and a core script
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/sql.lib.php';
-//require_once 'libraries/display_import_functions.lib.php';
 
 if (isset($_REQUEST['show_as_php'])) {
     $GLOBALS['show_as_php'] = $_REQUEST['show_as_php'];
 }
 
-// Import functions.
-require_once 'libraries/import.lib.php';
-
 // If there is a request to 'Simulate DML'.
 if (isset($_REQUEST['simulate_dml'])) {
-    PMA_handleSimulateDMLRequest();
+    Import::handleSimulateDmlRequest();
     exit;
 }
 
 $response = Response::getInstance();
 
+$sql = new Sql();
+
 // If it's a refresh console bookmarks request
 if (isset($_REQUEST['console_bookmark_refresh'])) {
     $response->addJSON(
-        'console_message_bookmark', PMA\libraries\Console::getBookmarkContent()
+        'console_message_bookmark', PhpMyAdmin\Console::getBookmarkContent()
     );
     exit;
 }
@@ -52,7 +55,7 @@ if (isset($_REQUEST['console_bookmark_add'])) {
     if (isset($_REQUEST['label']) && isset($_REQUEST['db'])
         && isset($_REQUEST['bookmark_query']) && isset($_REQUEST['shared'])
     ) {
-        $cfgBookmark = Bookmark::getParams();
+        $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
         $bookmarkFields = array(
             'bkm_database' => $_REQUEST['db'],
             'bkm_user'  => $cfgBookmark['user'],
@@ -60,7 +63,12 @@ if (isset($_REQUEST['console_bookmark_add'])) {
             'bkm_label' => $_REQUEST['label']
         );
         $isShared = ($_REQUEST['shared'] == 'true' ? true : false);
-        $bookmark = Bookmark::createBookmark($bookmarkFields, $isShared);
+        $bookmark = Bookmark::createBookmark(
+            $GLOBALS['dbi'],
+            $GLOBALS['cfg']['Server']['user'],
+            $bookmarkFields,
+            $isShared
+        );
         if ($bookmark !== false && $bookmark->save()) {
             $response->addJSON('message', __('Succeeded'));
             $response->addJSON('data', $bookmarkFields);
@@ -146,7 +154,7 @@ if (! empty($sql_query)) {
 
     // If there is a request to ROLLBACK when finished.
     if (isset($_REQUEST['rollback_query'])) {
-        PMA_handleRollbackRequest($import_text);
+        Import::handleRollbackRequest($import_text);
     }
 
     // refresh navigation and main panels
@@ -171,7 +179,7 @@ if (! empty($sql_query)) {
         $rename_table_names
     )) {
         $ajax_reload['reload'] = true;
-        $ajax_reload['table_name'] = PMA\libraries\Util::unQuote(
+        $ajax_reload['table_name'] = PhpMyAdmin\Util::unQuote(
             $rename_table_names[2]
         );
     }
@@ -192,7 +200,7 @@ if (! empty($sql_query)) {
 // If we didn't get any parameters, either user called this directly, or
 // upload limit has been reached, let's assume the second possibility.
 if ($_POST == array() && $_GET == array()) {
-    $message = PMA\libraries\Message::error(
+    $message = PhpMyAdmin\Message::error(
         __(
             'You probably tried to upload a file that is too large. Please refer ' .
             'to %sdocumentation%s for a workaround for this limit.'
@@ -236,7 +244,7 @@ if (! in_array(
 ) {
     // this should not happen for a normal user
     // but only during an attack
-    PMA_fatalError('Incorrect format parameter');
+    Core::fatalError('Incorrect format parameter');
 }
 
 $post_patterns = array(
@@ -244,13 +252,13 @@ $post_patterns = array(
     '/^' . $format . '_/'
 );
 
-PMA_setPostAsGlobal($post_patterns);
+Core::setPostAsGlobal($post_patterns);
 
 // Check needed parameters
-PMA\libraries\Util::checkParameters(array('import_type', 'format'));
+PhpMyAdmin\Util::checkParameters(array('import_type', 'format'));
 
 // We don't want anything special in format
-$format = PMA_securePath($format);
+$format = Core::securePath($format);
 
 if (strlen($table) > 0 && strlen($db) > 0) {
     $urlparams = array('db' => $db, 'table' => $table);
@@ -278,7 +286,7 @@ if ($import_type == 'table') {
         }
     }
 }
-$err_url = $goto . URL::getCommon($urlparams);
+$err_url = $goto . Url::getCommon($urlparams);
 $_SESSION['Import_message']['go_back_url'] = $err_url;
 // Avoid setting selflink to 'import.php'
 // problem similar to bug 4276
@@ -293,7 +301,7 @@ if (strlen($db) > 0) {
 
 Util::setTimeLimit();
 if (! empty($cfg['MemoryLimit'])) {
-    @ini_set('memory_limit', $cfg['MemoryLimit']);
+    ini_set('memory_limit', $cfg['MemoryLimit']);
 }
 
 $timestamp = time();
@@ -328,6 +336,8 @@ if (! empty($_REQUEST['id_bookmark'])) {
     switch ($_REQUEST['action_bookmark']) {
     case 0: // bookmarked query that have to be run
         $bookmark = Bookmark::get(
+            $GLOBALS['dbi'],
+            $GLOBALS['cfg']['Server']['user'],
             $db,
             $id_bookmark,
             'id',
@@ -361,10 +371,15 @@ if (! empty($_REQUEST['id_bookmark'])) {
         }
         break;
     case 1: // bookmarked query that have to be displayed
-        $bookmark = Bookmark::get($db, $id_bookmark);
+        $bookmark = Bookmark::get(
+            $GLOBALS['dbi'],
+            $GLOBALS['cfg']['Server']['user'],
+            $db,
+            $id_bookmark
+        );
         $import_text = $bookmark->getQuery();
         if ($response->isAjax()) {
-            $message = PMA\libraries\Message::success(__('Showing bookmark'));
+            $message = PhpMyAdmin\Message::success(__('Showing bookmark'));
             $response->setRequestStatus($message->isSuccess());
             $response->addJSON('message', $message);
             $response->addJSON('sql_query', $import_text);
@@ -375,11 +390,16 @@ if (! empty($_REQUEST['id_bookmark'])) {
         }
         break;
     case 2: // bookmarked query that have to be deleted
-        $bookmark = Bookmark::get($db, $id_bookmark);
+        $bookmark = Bookmark::get(
+            $GLOBALS['dbi'],
+            $GLOBALS['cfg']['Server']['user'],
+            $db,
+            $id_bookmark
+        );
         if (! empty($bookmark)) {
             $bookmark->delete();
             if ($response->isAjax()) {
-                $message = PMA\libraries\Message::success(
+                $message = PhpMyAdmin\Message::success(
                     __('The bookmark has been deleted.')
                 );
                 $response->setRequestStatus($message->isSuccess());
@@ -404,7 +424,7 @@ if (isset($GLOBALS['show_as_php'])) {
 }
 
 // We can not read all at once, otherwise we can run out of memory
-$memory_limit = trim(@ini_get('memory_limit'));
+$memory_limit = trim(ini_get('memory_limit'));
 // 2 MB as default
 if (empty($memory_limit)) {
     $memory_limit = 2 * 1024 * 1024;
@@ -436,9 +456,9 @@ if (isset($_FILES['import_file'])) {
 if (! empty($local_import_file) && ! empty($cfg['UploadDir'])) {
 
     // sanitize $local_import_file as it comes from a POST
-    $local_import_file = PMA_securePath($local_import_file);
+    $local_import_file = Core::securePath($local_import_file);
 
-    $import_file = PMA\libraries\Util::userDir($cfg['UploadDir'])
+    $import_file = PhpMyAdmin\Util::userDir($cfg['UploadDir'])
         . $local_import_file;
 
     /*
@@ -463,23 +483,23 @@ if ($import_file != 'none' && ! $error) {
     $import_handle = new File($import_file);
     $import_handle->checkUploadedFile();
     if ($import_handle->isError()) {
-        PMA_stopImport($import_handle->getError());
+        Import::stop($import_handle->getError());
     }
     $import_handle->setDecompressContent(true);
     $import_handle->open();
     if ($import_handle->isError()) {
-        PMA_stopImport($import_handle->getError());
+        Import::stop($import_handle->getError());
     }
 } elseif (! $error) {
     if (! isset($import_text) || empty($import_text)) {
-        $message = PMA\libraries\Message::error(
+        $message = PhpMyAdmin\Message::error(
             __(
                 'No data was received to import. Either no file name was ' .
                 'submitted, or the file size exceeded the maximum size permitted ' .
                 'by your PHP configuration. See [doc@faq1-16]FAQ 1.16[/doc].'
             )
         );
-        PMA_stopImport($message);
+        Import::stop($message);
     }
 }
 
@@ -502,7 +522,7 @@ if (Encoding::isSupported() && isset($charset_of_file)) {
 if (! $error && isset($_POST['skip'])) {
     $original_skip = $skip = intval($_POST['skip']);
     while ($skip > 0 && ! $finished) {
-        PMA_importGetNextChunk($skip < $read_limit ? $skip : $read_limit);
+        Import::getNextChunk($skip < $read_limit ? $skip : $read_limit);
         // Disable read progressivity, otherwise we eat all memory!
         $read_multiply = 1;
         $skip -= $read_limit;
@@ -515,28 +535,26 @@ if (! $error && isset($_POST['skip'])) {
 $sql_data = array('valid_sql' => array(), 'valid_queries' => 0);
 
 if (! $error) {
-    // Check for file existence
-    include_once "libraries/plugin_interface.lib.php";
     /* @var $import_plugin ImportPlugin */
-    $import_plugin = PMA_getPlugin(
+    $import_plugin = Plugins::getPlugin(
         "import",
         $format,
-        'libraries/plugins/import/',
+        'libraries/classes/Plugins/Import/',
         $import_type
     );
     if ($import_plugin == null) {
-        $message = PMA\libraries\Message::error(
+        $message = PhpMyAdmin\Message::error(
             __('Could not load import plugins, please check your installation!')
         );
-        PMA_stopImport($message);
+        Import::stop($message);
     } else {
         // Do the real import
         try {
-            $default_fk_check = PMA\libraries\Util::handleDisableFKCheckInit();
+            $default_fk_check = PhpMyAdmin\Util::handleDisableFKCheckInit();
             $import_plugin->doImport($sql_data);
-            PMA\libraries\Util::handleDisableFKCheckCleanup($default_fk_check);
+            PhpMyAdmin\Util::handleDisableFKCheckCleanup($default_fk_check);
         } catch (Exception $e) {
-            PMA\libraries\Util::handleDisableFKCheckCleanup($default_fk_check);
+            PhpMyAdmin\Util::handleDisableFKCheckCleanup($default_fk_check);
             throw $e;
         }
     }
@@ -553,19 +571,17 @@ if ($file_to_unlink != '') {
 
 // Reset charset back, if we did some changes
 if ($reset_charset) {
-    $GLOBALS['dbi']->query('SET CHARACTER SET utf8');
-    $GLOBALS['dbi']->query(
-        'SET SESSION collation_connection =\'' . $collation_connection . '\''
-    );
+    $GLOBALS['dbi']->query('SET CHARACTER SET ' . $GLOBALS['charset_connection']);
+    $GLOBALS['dbi']->setCollationConnection($collation_connection);
 }
 
 // Show correct message
 if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
-    $message = PMA\libraries\Message::success(__('The bookmark has been deleted.'));
+    $message = PhpMyAdmin\Message::success(__('The bookmark has been deleted.'));
     $display_query = $import_text;
     $error = false; // unset error marker, it was used just to skip processing
 } elseif (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 1) {
-    $message = PMA\libraries\Message::notice(__('Showing bookmark'));
+    $message = PhpMyAdmin\Message::notice(__('Showing bookmark'));
 } elseif ($bookmark_created) {
     $special_message = '[br]'  . sprintf(
         __('Bookmark %s has been created.'),
@@ -575,7 +591,7 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
     // Do not display the query with message, we do it separately
     $display_query = ';';
     if ($import_type != 'query') {
-        $message = PMA\libraries\Message::success(
+        $message = PhpMyAdmin\Message::success(
             '<em>'
             . _ngettext(
                 'Import has been successfully finished, %d query executed.',
@@ -586,7 +602,7 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
         );
         $message->addParam($executed_queries);
 
-        if ($import_notice) {
+        if (! empty($import_notice)) {
             $message->addHtml($import_notice);
         }
         if (! empty($local_import_file)) {
@@ -605,9 +621,9 @@ if ($timeout_passed) {
         $urlparams['local_import_file'] = $local_import_file;
     }
 
-    $importUrl = $err_url = $goto . URL::getCommon($urlparams);
+    $importUrl = $err_url = $goto . Url::getCommon($urlparams);
 
-    $message = PMA\libraries\Message::error(
+    $message = PhpMyAdmin\Message::error(
         __(
             'Script timeout passed, if you want to finish import,'
             . ' please %sresubmit the same file%s and import will resume.'
@@ -638,13 +654,11 @@ if (isset($message)) {
 //  can choke on it so avoid parsing)
 $sqlLength = mb_strlen($sql_query);
 if ($sqlLength <= $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
-    include_once 'libraries/parse_analyze.lib.php';
-
     list(
         $analyzed_sql_results,
         $db,
         $table_from_sql
-    ) = PMA_parseAnalyze($sql_query, $db);
+    ) = ParseAnalyze::sqlQuery($sql_query, $db);
     // @todo: possibly refactor
     extract($analyzed_sql_results);
 
@@ -656,7 +670,7 @@ if ($sqlLength <= $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
 // There was an error?
 if (isset($my_die)) {
     foreach ($my_die as $key => $die) {
-        PMA\libraries\Util::mysqlDie(
+        PhpMyAdmin\Util::mysqlDie(
             $die['error'], $die['sql'], false, $err_url, $error
         );
     }
@@ -676,20 +690,19 @@ if ($go_sql) {
     foreach ($sql_queries as $sql_query) {
 
         // parse sql query
-        include_once 'libraries/parse_analyze.lib.php';
         list(
             $analyzed_sql_results,
             $db,
             $table_from_sql
-        ) = PMA_parseAnalyze($sql_query, $db);
+        ) = ParseAnalyze::sqlQuery($sql_query, $db);
         // @todo: possibly refactor
         extract($analyzed_sql_results);
 
         // Check if User is allowed to issue a 'DROP DATABASE' Statement
-        if (PMA_hasNoRightsToDropDatabase(
-            $analyzed_sql_results, $cfg['AllowUserDropDatabase'], $GLOBALS['is_superuser']
+        if ($sql->hasNoRightsToDropDatabase(
+            $analyzed_sql_results, $cfg['AllowUserDropDatabase'], $GLOBALS['dbi']->isSuperuser()
         )) {
-            PMA\libraries\Util::mysqlDie(
+            PhpMyAdmin\Util::mysqlDie(
                 __('"DROP DATABASE" statements are disabled.'),
                 '',
                 false,
@@ -702,7 +715,7 @@ if ($go_sql) {
             $table = $table_from_sql;
         }
 
-        $html_output .= PMA_executeQueryAndGetQueryResponse(
+        $html_output .= $sql->executeQueryAndGetQueryResponse(
             $analyzed_sql_results, // analyzed_sql_results
             false, // is_gotofile
             $db, // db
@@ -724,14 +737,14 @@ if ($go_sql) {
         );
     }
 
-    // sql_query_for_bookmark is not included in PMA_executeQueryAndGetQueryResponse
+    // sql_query_for_bookmark is not included in Sql::executeQueryAndGetQueryResponse
     // since only one bookmark has to be added for all the queries submitted through
     // the SQL tab
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
-        $cfgBookmark = Bookmark::getParams();
-        PMA_storeTheQueryAsBookmark(
+        $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
+        $sql->storeTheQueryAsBookmark(
             $db, $cfgBookmark['user'],
-            $_REQUEST['sql_query'], $_POST['bkm_label'],
+            $_POST['sql_query'], $_POST['bkm_label'],
             isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
         );
     }
@@ -740,26 +753,26 @@ if ($go_sql) {
     $response->addHTML($html_output);
     exit();
 
-} else if ($result) {
+} elseif ($result) {
     // Save a Bookmark with more than one queries (if Bookmark label given).
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
-        $cfgBookmark = Bookmark::getParams();
-        PMA_storeTheQueryAsBookmark(
+        $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
+        $sql->storeTheQueryAsBookmark(
             $db, $cfgBookmark['user'],
-            $_REQUEST['sql_query'], $_POST['bkm_label'],
+            $_POST['sql_query'], $_POST['bkm_label'],
             isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
         );
     }
 
     $response->setRequestStatus(true);
-    $response->addJSON('message', PMA\libraries\Message::success($msg));
+    $response->addJSON('message', PhpMyAdmin\Message::success($msg));
     $response->addJSON(
         'sql_query',
-        PMA\libraries\Util::getMessage($msg, $sql_query, 'success')
+        PhpMyAdmin\Util::getMessage($msg, $sql_query, 'success')
     );
-} else if ($result == false) {
+} elseif ($result == false) {
     $response->setRequestStatus(false);
-    $response->addJSON('message', PMA\libraries\Message::error($msg));
+    $response->addJSON('message', PhpMyAdmin\Message::error($msg));
 } else {
     $active_page = $goto;
     include '' . $goto;
