@@ -12,9 +12,8 @@
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('server_databases.js', function () {
-    $(document).off('submit', "#dbStatsForm");
+    $(document).off('submit', '#dbStatsForm');
     $(document).off('submit', '#create_database_form.ajax');
-    $('#filterText').unbind('keyup');
 });
 
 /**
@@ -28,7 +27,7 @@ AJAX.registerOnload('server_databases.js', function () {
     /**
      * Attach Event Handler for 'Drop Databases'
      */
-    $(document).on('submit', "#dbStatsForm", function (event) {
+    $(document).on('submit', '#dbStatsForm', function (event) {
         event.preventDefault();
 
         var $form = $(this);
@@ -57,22 +56,22 @@ AJAX.registerOnload('server_databases.js', function () {
         var question = PMA_messages.strDropDatabaseStrongWarning + ' ' +
             PMA_sprintf(PMA_messages.strDoYouReally, selected_dbs.join('<br />'));
 
+        var argsep = PMA_commonParams.get('arg_separator');
         $(this).PMA_confirm(
             question,
             $form.prop('action') + '?' + $(this).serialize() +
-                '&drop_selected_dbs=1&is_js_confirmed=1&ajax_request=true',
+                argsep + 'drop_selected_dbs=1' + argsep + 'is_js_confirmed=1' + argsep + 'ajax_request=true',
             function (url) {
                 PMA_ajaxShowMessage(PMA_messages.strProcessingRequest, false);
 
                 var params = getJSConfirmCommonParam(this);
-                params.token = PMA_commonParams.get('token');
 
                 $.post(url, params, function (data) {
                     if (typeof data !== 'undefined' && data.success === true) {
                         PMA_ajaxShowMessage(data.message);
 
                         var $rowsToRemove = $form.find('tr.removeMe');
-                        var $databasesCount = $('#databases_count');
+                        var $databasesCount = $('#filter-rows-count');
                         var newCount = parseInt($databasesCount.text(), 10) - $rowsToRemove.length;
                         $databasesCount.text(newCount);
 
@@ -90,7 +89,7 @@ AJAX.registerOnload('server_databases.js', function () {
                 }); // end $.post()
             }
         ); // end $.PMA_confirm()
-    }); //end of Drop Database action
+    }); // end of Drop Database action
 
     /**
      * Attach Ajax event handlers for 'Create Database'.
@@ -116,7 +115,7 @@ AJAX.registerOnload('server_databases.js', function () {
             if (typeof data !== 'undefined' && data.success === true) {
                 PMA_ajaxShowMessage(data.message);
 
-                var $databases_count_object = $('#databases_count');
+                var $databases_count_object = $('#filter-rows-count');
                 var databases_count = parseInt($databases_count_object.text(), 10) + 1;
                 $databases_count_object.text(databases_count);
                 PMA_reloadNavigation();
@@ -124,7 +123,7 @@ AJAX.registerOnload('server_databases.js', function () {
                 // make ajax request to load db structure page - taken from ajax.js
                 var dbStruct_url = data.url_query;
                 dbStruct_url = dbStruct_url.replace(/amp;/ig, '');
-                var params = 'ajax_request=true&ajax_page_request=true';
+                var params = 'ajax_request=true' + PMA_commonParams.get('arg_separator') + 'ajax_page_request=true';
                 if (! (history && history.pushState)) {
                     params += PMA_MicroHistory.menus.getRequestParam();
                 }
@@ -136,51 +135,15 @@ AJAX.registerOnload('server_databases.js', function () {
     }); // end $(document).on()
 
     /* Don't show filter if number of databases are very few */
-    var databasesCount = $('#databases_count').html();
-    if(databasesCount <= 10) {
+    var databasesCount = $('#filter-rows-count').html();
+    if (databasesCount <= 10) {
         $('#tableFilter').hide();
     }
 
-    var $filterField = $('#filterText');
-    /* Event handler for database filter */
-    $filterField.keyup(function (){
-       var textFilter = null, val = $(this).val();
-       if(val.length != 0) {
-           try {
-               textFilter = new RegExp(val.replace(/_/g, ' '), 'i');
-               $(this).removeClass('error');
-           } catch(e) {
-               if (e instanceof SyntaxError) {
-                   $(this).addClass('error');
-                   textFilter = null;
-               }
-           }
-       }
-       filterVariables(textFilter);
-    });
-
-    /* Trigger filtering of the list based on incoming database name */
-    if ($filterField.val()) {
-        $filterField.trigger('keyup').select();
-    }
-
-    /* Filters the rows by the user given regexp */
-    function filterVariables(textFilter) {
-        var $row, databasesCount = 0;
-        $('#tabledatabases').find('.db-row').each(function () {
-            $row = $(this);
-            if (textFilter === null ||
-                textFilter.exec($row.find('.name').text())
-               ) {
-                   $row.css('display', '');
-                   databasesCount += 1;
-                   $row.find('input.checkall').removeClass('row-hidden').trigger('change');
-               } else {
-                   $row.css('display', 'none');
-                   $row.find('input.checkall').addClass('row-hidden').prop('checked', false).trigger('change');
-                   $row.removeClass('marked');
-               }
-            $('#databases_count').html(databasesCount);
+    var tableRows = $('.server_databases');
+    $.each(tableRows, function (index, item) {
+        $(this).click(function () {
+            PMA_commonActions.setDb($(this).attr('data'));
         });
-    }
+    });
 }); // end $()
