@@ -18,79 +18,42 @@
  *
  */
 
-/**
- * This function returns the horizontal space available for the menu in pixels.
- * To calculate this value we start we the width of the main panel, then we
- * substract the margin of the page content, then we substract any cellspacing
- * that the table may have (original theme only) and finally we substract the
- * width of all columns of the table except for the last one (which is where
- * the menu will go). What we should end up with is the distance between the
- * start of the last column on the table and the edge of the page, again this
- * is the space available for the menu.
- *
- * In the case where the table cell where the menu will be displayed is already
- * off-screen (the table is wider than the page), a negative value will be returned,
- * but this will be treated as a zero by the menuResizer plugin.
- *
- * @return int
- */
-function PMA_tbl_structure_menu_resizer_callback() {
-    var pagewidth = $('body').width();
-    var $page = $('#page_content');
-    pagewidth -= $page.outerWidth(true) - $page.outerWidth();
-    var columnsWidth = 0;
-    var $columns = $('#tablestructure').find('tr:eq(1)').find('td,th');
-    $columns.not(':last').each(function () {
-        columnsWidth += $(this).outerWidth(true);
-    });
-    var totalCellSpacing = $('#tablestructure').width();
-    $columns.each(function () {
-        totalCellSpacing -= $(this).outerWidth(true);
-    });
-    return pagewidth - columnsWidth - totalCellSpacing - 15; // 15px extra margin
-}
-
 /**
  * Reload fields table
  */
-function reloadFieldForm() {
-    $.post($("#fieldsForm").attr('action'), $("#fieldsForm").serialize() + "&ajax_request=true", function (form_data) {
-        var $temp_div = $("<div id='temp_div'><div>").append(form_data.message);
-        $("#fieldsForm").replaceWith($temp_div.find("#fieldsForm"));
-        $("#addColumns").replaceWith($temp_div.find("#addColumns"));
-        $('#move_columns_dialog').find('ul').replaceWith($temp_div.find("#move_columns_dialog ul"));
-        $("#moveColumns").removeClass("move-active");
-        /* reinitialise the more options in table */
-        if ($('#fieldsForm').hasClass('HideStructureActions')) {
-            $('#fieldsForm').find('ul.table-structure-actions').menuResizer(PMA_tbl_structure_menu_resizer_callback);
-        }
+function reloadFieldForm () {
+    $.post($('#fieldsForm').attr('action'), $('#fieldsForm').serialize() + PMA_commonParams.get('arg_separator') + 'ajax_request=true', function (form_data) {
+        var $temp_div = $('<div id=\'temp_div\'><div>').append(form_data.message);
+        $('#fieldsForm').replaceWith($temp_div.find('#fieldsForm'));
+        $('#addColumns').replaceWith($temp_div.find('#addColumns'));
+        $('#move_columns_dialog').find('ul').replaceWith($temp_div.find('#move_columns_dialog ul'));
+        $('#moveColumns').removeClass('move-active');
     });
     $('#page_content').show();
 }
 
-function checkFirst() {
-    if ($("select[name=after_field] option:selected").data('pos') === 'first') {
-        $("input[name=field_where]").val('first');
+function checkFirst () {
+    if ($('select[name=after_field] option:selected').data('pos') === 'first') {
+        $('input[name=field_where]').val('first');
     } else {
-        $("input[name=field_where]").val('after');
+        $('input[name=field_where]').val('after');
     }
 }
 /**
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('tbl_structure.js', function () {
-    $(document).off('click', "a.drop_column_anchor.ajax");
-    $(document).off('click', "a.add_key.ajax");
-    $(document).off('click', "#move_columns_anchor");
-    $(document).off('click', "#printView");
-    $(document).off('submit', ".append_fields_form.ajax");
+    $(document).off('click', 'a.drop_column_anchor.ajax');
+    $(document).off('click', 'a.add_key.ajax');
+    $(document).off('click', '#move_columns_anchor');
+    $(document).off('click', '#printView');
+    $(document).off('submit', '.append_fields_form.ajax');
     $('body').off('click', '#fieldsForm.ajax button[name="submit_mult"], #fieldsForm.ajax input[name="submit_mult"]');
     $(document).off('click', 'a[name^=partition_action].ajax');
     $(document).off('click', '#remove_partitioning.ajax');
 });
 
 AJAX.registerOnload('tbl_structure.js', function () {
-
     // Re-initialize variables.
     primary_indexes = [];
     indexes = [];
@@ -100,8 +63,8 @@ AJAX.registerOnload('tbl_structure.js', function () {
     /**
      *Ajax action for submitting the "Column Change" and "Add Column" form
      */
-    $(".append_fields_form.ajax").off();
-    $(document).on('submit', ".append_fields_form.ajax", function (event) {
+    $('.append_fields_form.ajax').off();
+    $(document).on('submit', '.append_fields_form.ajax', function (event) {
         event.preventDefault();
         /**
          * @var    the_form    object referring to the export form
@@ -110,21 +73,21 @@ AJAX.registerOnload('tbl_structure.js', function () {
         var field_cnt = $form.find('input[name=orig_num_fields]').val();
 
 
-        function submitForm(){
+        function submitForm () {
             $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            $.post($form.attr('action'), $form.serialize() + '&do_save_data=1', function (data) {
-                if ($(".sqlqueryresults").length !== 0) {
-                    $(".sqlqueryresults").remove();
-                } else if ($(".error:not(.tab)").length !== 0) {
-                    $(".error:not(.tab)").remove();
+            $.post($form.attr('action'), $form.serialize() + PMA_commonParams.get('arg_separator') + 'do_save_data=1', function (data) {
+                if ($('.sqlqueryresults').length !== 0) {
+                    $('.sqlqueryresults').remove();
+                } else if ($('.error:not(.tab)').length !== 0) {
+                    $('.error:not(.tab)').remove();
                 }
-                if (typeof data.success != 'undefined' && data.success === true) {
-                    $("#page_content")
+                if (typeof data.success !== 'undefined' && data.success === true) {
+                    $('#page_content')
                         .empty()
                         .append(data.message)
                         .show();
                     PMA_highlightSQL($('#page_content'));
-                    $(".result_query .notice").remove();
+                    $('.result_query .notice').remove();
                     reloadFieldForm();
                     $form.remove();
                     PMA_ajaxRemoveMessage($msg);
@@ -136,19 +99,25 @@ AJAX.registerOnload('tbl_structure.js', function () {
             }); // end $.post()
         }
 
-        function checkIfConfirmRequired($form, $field_cnt) {
-            var i = 0, id, elm, val, name_orig, elm_orig, val_orig;
+        function checkIfConfirmRequired ($form, $field_cnt) {
+            var i = 0;
+            var id;
+            var elm;
+            var val;
+            var name_orig;
+            var elm_orig;
+            var val_orig;
             var checkRequired = false;
             for (i = 0; i < field_cnt; i++) {
-                id = "#field_" + i + "_5";
+                id = '#field_' + i + '_5';
                 elm = $(id);
                 val = elm.val();
 
-                name_orig = "input[name=field_collation_orig\\[" + i + "\\]]";
+                name_orig = 'input[name=field_collation_orig\\[' + i + '\\]]';
                 elm_orig = $form.find(name_orig);
                 val_orig = elm_orig.val();
 
-                if (val && val_orig && val !== val_orig){
+                if (val && val_orig && val !== val_orig) {
                     checkRequired = true;
                     break;
                 }
@@ -168,10 +137,10 @@ AJAX.registerOnload('tbl_structure.js', function () {
 
             PMA_prepareForAjaxRequest($form);
             if (PMA_checkReservedWordColumns($form)) {
-                //User wants to submit the form
+                // User wants to submit the form
 
                 // If Collation is changed, Warn and Confirm
-                if (checkIfConfirmRequired($form, field_cnt)){
+                if (checkIfConfirmRequired($form, field_cnt)) {
                     var question = sprintf(
                         PMA_messages.strChangeColumnCollation, 'https://wiki.phpmyadmin.net/pma/Garbled_data'
                     );
@@ -188,7 +157,7 @@ AJAX.registerOnload('tbl_structure.js', function () {
     /**
      * Attach Event Handler for 'Drop Column'
      */
-    $(document).on('click', "a.drop_column_anchor.ajax", function (event) {
+    $(document).on('click', 'a.drop_column_anchor.ajax', function (event) {
         event.preventDefault();
         /**
          * @var curr_table_name String containing the name of the current table
@@ -206,7 +175,7 @@ AJAX.registerOnload('tbl_structure.js', function () {
         /**
          * @var $after_field_item    Corresponding entry in the 'After' field.
          */
-        var $after_field_item = $("select[name='after_field'] option[value='" + curr_column_name + "']");
+        var $after_field_item = $('select[name=\'after_field\'] option[value=\'' + curr_column_name + '\']');
         /**
          * @var question    String containing the question to be asked for confirmation
          */
@@ -215,7 +184,7 @@ AJAX.registerOnload('tbl_structure.js', function () {
         $this_anchor.PMA_confirm(question, $this_anchor.attr('href'), function (url) {
             var $msg = PMA_ajaxShowMessage(PMA_messages.strDroppingColumn, false);
             var params = getJSConfirmCommonParam(this, $this_anchor.getPostData());
-            params += '&ajax_page_request=1';
+            params += PMA_commonParams.get('arg_separator') + 'ajax_page_request=1';
             $.post(url, params, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxRemoveMessage($msg);
@@ -234,18 +203,18 @@ AJAX.registerOnload('tbl_structure.js', function () {
                         $row.find('td:nth-child(2)').text(new_val);
                     }
                     $after_field_item.remove();
-                    $curr_row.hide("medium").remove();
+                    $curr_row.hide('medium').remove();
 
                     // Remove the dropped column from select menu for 'after field'
-                    $("select[name=after_field]").find(
+                    $('select[name=after_field]').find(
                         '[value="' + curr_column_name + '"]'
                     ).remove();
 
                     // by default select the (new) last option to add new column
                     // (in case last column is dropped)
-                    $("select[name=after_field] option:last").attr("selected","selected");
+                    $('select[name=after_field] option:last').attr('selected','selected');
 
-                    //refresh table stats
+                    // refresh table stats
                     if (data.tableStat) {
                         $('#tablestatistics').html(data.tableStat);
                     }
@@ -253,26 +222,26 @@ AJAX.registerOnload('tbl_structure.js', function () {
                     $('.index_info').replaceWith(data.indexes_list);
                     PMA_reloadNavigation();
                 } else {
-                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
+                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + ' : ' + data.error, false);
                 }
             }); // end $.post()
         }); // end $.PMA_confirm()
-    }); //end of Drop Column Anchor action
+    }); // end of Drop Column Anchor action
 
     /**
      * Attach Event Handler for 'Print' link
      */
-    $(document).on('click', "#printView", function (event) {
+    $(document).on('click', '#printView', function (event) {
         event.preventDefault();
 
         // Take to preview mode
         printPreview();
-    }); //end of Print View action
+    }); // end of Print View action
 
     /**
      * Ajax Event handler for adding keys
      */
-    $(document).on('click', "a.add_key.ajax", function (event) {
+    $(document).on('click', 'a.add_key.ajax', function (event) {
         event.preventDefault();
 
         var $this = $(this);
@@ -301,18 +270,18 @@ AJAX.registerOnload('tbl_structure.js', function () {
             AJAX.source = $this;
 
             var params = getJSConfirmCommonParam(this, $this_anchor.getPostData());
-            params += '&ajax_page_request=1';
+            params += PMA_commonParams.get('arg_separator') + 'ajax_page_request=1';
             $.post(url, params, AJAX.responseHandler);
         }); // end $.PMA_confirm()
-    }); //end Add key
+    }); // end Add key
 
     /**
      * Inline move columns
     **/
-    $(document).on('click', "#move_columns_anchor", function (e) {
+    $(document).on('click', '#move_columns_anchor', function (e) {
         e.preventDefault();
 
-        if ($(this).hasClass("move-active")) {
+        if ($(this).hasClass('move-active')) {
             return;
         }
 
@@ -326,61 +295,55 @@ AJAX.registerOnload('tbl_structure.js', function () {
             event.preventDefault();
             var $msgbox = PMA_ajaxShowMessage();
             var $this = $(this);
-            var $form = $this.find("form");
+            var $form = $this.find('form');
             var serialized = $form.serialize();
 
             // check if any columns were moved at all
-            if (serialized == $form.data("serialized-unmoved")) {
+            if (serialized === $form.data('serialized-unmoved')) {
                 PMA_ajaxRemoveMessage($msgbox);
                 $this.dialog('close');
                 return;
             }
 
-            $.post($form.prop("action"), serialized + "&ajax_request=true", function (data) {
+            $.post($form.prop('action'), serialized + PMA_commonParams.get('arg_separator') + 'ajax_request=true', function (data) {
                 if (data.success === false) {
                     PMA_ajaxRemoveMessage($msgbox);
                     $this
-                    .clone()
-                    .html(data.error)
-                    .dialog({
-                        title: $(this).prop("title"),
-                        height: 230,
-                        width: 900,
-                        modal: true,
-                        buttons: button_options_error
-                    }); // end dialog options
+                        .clone()
+                        .html(data.error)
+                        .dialog({
+                            title: $(this).prop('title'),
+                            height: 230,
+                            width: 900,
+                            modal: true,
+                            buttons: button_options_error
+                        }); // end dialog options
                 } else {
-                    if ($('#fieldsForm').hasClass('HideStructureActions')) {
-                        $('#fieldsForm').find('ul.table-structure-actions').menuResizer('destroy');
-                    }
                     // sort the fields table
-                    var $fields_table = $("table#tablestructure tbody");
+                    var $fields_table = $('table#tablestructure tbody');
                     // remove all existing rows and remember them
-                    var $rows = $fields_table.find("tr").remove();
+                    var $rows = $fields_table.find('tr').remove();
                     // loop through the correct order
                     for (var i in data.columns) {
                         var the_column = data.columns[i];
                         var $the_row = $rows
-                            .find("input:checkbox[value='" + the_column + "']")
-                            .closest("tr");
+                            .find('input:checkbox[value=\'' + the_column + '\']')
+                            .closest('tr');
                         // append the row for this column to the table
                         $fields_table.append($the_row);
                     }
-                    var $firstrow = $fields_table.find("tr").eq(0);
+                    var $firstrow = $fields_table.find('tr').eq(0);
                     // Adjust the row numbers and colors
                     for (var $row = $firstrow; $row.length > 0; $row = $row.next()) {
                         $row
-                        .find('td:nth-child(2)')
-                        .text($row.index() + 1)
-                        .end()
-                        .removeClass("odd even")
-                        .addClass($row.index() % 2 === 0 ? "odd" : "even");
+                            .find('td:nth-child(2)')
+                            .text($row.index() + 1)
+                            .end()
+                            .removeClass('odd even')
+                            .addClass($row.index() % 2 === 0 ? 'odd' : 'even');
                     }
                     PMA_ajaxShowMessage(data.message);
                     $this.dialog('close');
-                    if ($('#fieldsForm').hasClass('HideStructureActions')) {
-                        $('#fieldsForm').find('ul.table-structure-actions').menuResizer(PMA_tbl_structure_menu_resizer_callback);
-                    }
                 }
             });
         };
@@ -395,43 +358,43 @@ AJAX.registerOnload('tbl_structure.js', function () {
 
         var columns = [];
 
-        $("#tablestructure").find("tbody tr").each(function () {
-            var col_name = $(this).find("input:checkbox").eq(0).val();
-            var hidden_input = $("<input/>")
+        $('#tablestructure').find('tbody tr').each(function () {
+            var col_name = $(this).find('input:checkbox').eq(0).val();
+            var hidden_input = $('<input/>')
                 .prop({
-                    name: "move_columns[]",
-                    type: "hidden"
+                    name: 'move_columns[]',
+                    type: 'hidden'
                 })
                 .val(col_name);
-            columns[columns.length] = $("<li/>")
-                .addClass("placeholderDrag")
+            columns[columns.length] = $('<li/>')
+                .addClass('placeholderDrag')
                 .text(col_name)
                 .append(hidden_input);
         });
 
-        var col_list = $("#move_columns_dialog").find("ul")
-            .find("li").remove().end();
+        var col_list = $('#move_columns_dialog').find('ul')
+            .find('li').remove().end();
         for (var i in columns) {
             col_list.append(columns[i]);
         }
         col_list.sortable({
             axis: 'y',
-            containment: $("#move_columns_dialog").find("div"),
+            containment: $('#move_columns_dialog').find('div'),
             tolerance: 'pointer'
         }).disableSelection();
-        var $form = $("#move_columns_dialog").find("form");
-        $form.data("serialized-unmoved", $form.serialize());
+        var $form = $('#move_columns_dialog').find('form');
+        $form.data('serialized-unmoved', $form.serialize());
 
-        $("#move_columns_dialog").dialog({
+        $('#move_columns_dialog').dialog({
             modal: true,
             buttons: button_options,
             open: function () {
                 if ($('#move_columns_dialog').parents('.ui-dialog').height() > $(window).height()) {
-                    $('#move_columns_dialog').dialog("option", "height", $(window).height());
+                    $('#move_columns_dialog').dialog('option', 'height', $(window).height());
                 }
             },
             beforeClose: function () {
-                $("#move_columns_anchor").removeClass("move-active");
+                $('#move_columns_anchor').removeClass('move-active');
             }
         });
     });
@@ -443,7 +406,8 @@ AJAX.registerOnload('tbl_structure.js', function () {
         e.preventDefault();
         var $button = $(this);
         var $form = $button.parents('form');
-        var submitData = $form.serialize() + '&ajax_request=true&ajax_page_request=true&submit_mult=' + $button.val();
+        var argsep = PMA_commonParams.get('arg_separator');
+        var submitData = $form.serialize() + argsep + 'ajax_request=true' + argsep + 'ajax_page_request=true' + argsep + 'submit_mult=' + $button.val();
         PMA_ajaxShowMessage();
         AJAX.source = $form;
         $.post($form.attr('action'), submitData, AJAX.responseHandler);
@@ -456,11 +420,10 @@ AJAX.registerOnload('tbl_structure.js', function () {
         e.preventDefault();
         var $link = $(this);
 
-        function submitPartitionAction(url) {
+        function submitPartitionAction (url) {
             var params = {
                 'ajax_request' : true,
-                'ajax_page_request' : true,
-                'token': PMA_commonParams.get('token')
+                'ajax_page_request' : true
             };
             PMA_ajaxShowMessage();
             AJAX.source = $link;
@@ -492,39 +455,49 @@ AJAX.registerOnload('tbl_structure.js', function () {
         $link.PMA_confirm(question, $link.attr('href'), function (url) {
             var params = {
                 'ajax_request' : true,
-                'ajax_page_request' : true,
-                'token': PMA_commonParams.get('token')
+                'ajax_page_request' : true
             };
             PMA_ajaxShowMessage();
             AJAX.source = $link;
             $.post(url, params, AJAX.responseHandler);
         });
     });
+
+    $(document).on('change', 'select[name=after_field]', function () {
+        checkFirst();
+    });
 });
 
 /** Handler for "More" dropdown in structure table rows */
 AJAX.registerOnload('tbl_structure.js', function () {
-    if ($('#fieldsForm').hasClass('HideStructureActions')) {
-        $('#fieldsForm').find('ul.table-structure-actions').menuResizer(PMA_tbl_structure_menu_resizer_callback);
-    } else {
-        $('.table-structure-actions').width(function () {
-            var width = 5;
-            $(this).find('li').each(function () {
-                width += $(this).outerWidth(true);
+    var windowwidth = $(window).width();
+    if (windowwidth > 768) {
+        if (! $('#fieldsForm').hasClass('HideStructureActions')) {
+            $('.table-structure-actions').width(function () {
+                var width = 5;
+                $(this).find('li').each(function () {
+                    width += $(this).outerWidth(true);
+                });
+                return width;
             });
-            return width;
-        });
-    }
-});
-AJAX.registerTeardown('tbl_structure.js', function () {
-    if ($('#fieldsForm').hasClass('HideStructureActions')) {
-        $('#fieldsForm').find('ul.table-structure-actions').menuResizer('destroy');
-    }
-});
-$(function () {
-    $(window).resize($.throttle(function () {
-        if ($('#fieldsForm').length && $('#fieldsForm').hasClass('HideStructureActions')) {
-            $('#fieldsForm').find('ul.table-structure-actions').menuResizer('resize');
         }
-    }));
+    }
+
+    $('.jsresponsive').css('max-width', (windowwidth - 35) + 'px');
+    var tableRows = $('.central_columns');
+    $.each(tableRows, function (index, item) {
+        if ($(item).hasClass('add_button')) {
+            $(item).click(function () {
+                $('input:checkbox').prop('checked', false);
+                $('#checkbox_row_' + (index + 1)).prop('checked', true);
+                $('button[value=add_to_central_columns]').click();
+            });
+        } else {
+            $(item).click(function () {
+                $('input:checkbox').prop('checked', false);
+                $('#checkbox_row_' + (index + 1)).prop('checked', true);
+                $('button[value=remove_from_central_columns]').click();
+            });
+        }
+    });
 });
