@@ -5,9 +5,14 @@
  *
  * @package PhpMyAdmin
  */
-use PMA\libraries\Partition;
-use PMA\libraries\Table;
-use PMA\libraries\Response;
+use PhpMyAdmin\Index;
+use PhpMyAdmin\Message;
+use PhpMyAdmin\Partition;
+use PhpMyAdmin\Operations;
+use PhpMyAdmin\Relation;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Table;
+use PhpMyAdmin\Util;
 
 /**
  *
@@ -17,8 +22,7 @@ require_once 'libraries/common.inc.php';
 /**
  * functions implementation for this script
  */
-require_once 'libraries/check_user_privileges.lib.php';
-require_once 'libraries/operations.lib.php';
+require_once 'libraries/check_user_privileges.inc.php';
 
 $pma_table = new Table($GLOBALS['table'], $GLOBALS['db']);
 
@@ -40,23 +44,43 @@ $url_params['goto'] = $url_params['back'] = 'tbl_operations.php';
 /**
  * Gets relation settings
  */
-$cfgRelation = PMA_getRelationsParam();
+$relation = new Relation();
+$cfgRelation = $relation->getRelationsParam();
 
 // reselect current db (needed in some cases probably due to
-// the calling of relation.lib.php)
+// the calling of PhpMyAdmin\Relation)
 $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 
 /**
  * Gets tables information
  */
-require 'libraries/tbl_info.inc.php';
+$pma_table = $GLOBALS['dbi']->getTable(
+    $GLOBALS['db'],
+    $GLOBALS['table']
+);
+$reread_info = $pma_table->getStatusInfo(null, false);
+$GLOBALS['showtable'] = $pma_table->getStatusInfo(null, (isset($reread_info) && $reread_info ? true : false));
+if ($pma_table->isView()) {
+    $tbl_is_view = true;
+    $tbl_storage_engine = __('View');
+    $show_comment = null;
+} else {
+    $tbl_is_view = false;
+    $tbl_storage_engine = $pma_table->getStorageEngine();
+    $show_comment = $pma_table->getComment();
+}
+$tbl_collation = $pma_table->getCollation();
+$table_info_num_rows = $pma_table->getNumRows();
+$row_format = $pma_table->getRowFormat();
+$auto_increment = $pma_table->getAutoIncrement();
+$create_options = $pma_table->getCreateOptions();
 
 // set initial value of these variables, based on the current table engine
 if ($pma_table->isEngine('ARIA')) {
     // the value for transactional can be implicit
     // (no create option found, in this case it means 1)
     // or explicit (option found with a value of 0 or 1)
-    // ($create_options['transactional'] may have been set by libraries/tbl_info.inc.php,
+    // ($create_options['transactional'] may have been set by Table class,
     // from the $create_options)
     $create_options['transactional'] = (isset($create_options['transactional']) && $create_options['transactional'] == '0')
         ? '0'
@@ -64,15 +88,21 @@ if ($pma_table->isEngine('ARIA')) {
     $create_options['page_checksum'] = (isset($create_options['page_checksum'])) ? $create_options['page_checksum'] : '';
 }
 
+$pma_table = $GLOBALS['dbi']->getTable(
+    $GLOBALS['db'],
+    $GLOBALS['table']
+);
 $reread_info = false;
 $table_alters = array();
 
+$operations = new Operations();
+
 /**
  * If the table has to be moved to some other database
  */
 if (isset($_REQUEST['submit_move']) || isset($_REQUEST['submit_copy'])) {
     //$_message = '';
-    PMA_moveOrCopyTable($db, $table);
+    $operations->moveOrCopyTable($db, $table);
     // This was ended in an Ajax call
     exit;
 }
@@ -99,7 +129,7 @@ if (isset($_REQUEST['submitoptions'])) {
             if (isset($_REQUEST['adjust_privileges'])
                 && ! empty($_REQUEST['adjust_privileges'])
             ) {
-                PMA_AdjustPrivileges_renameOrMoveTable(
+                $operations->adjustPrivilegesRenameOrMoveTable(
                     $oldDb, $oldTable, $_REQUEST['db'], $_REQUEST['new_name']
                 );
             }
@@ -107,7 +137,6 @@ if (isset($_REQUEST['submitoptions'])) {
             // Reselect the original DB
             $GLOBALS['db'] = $oldDb;
             $GLOBALS['dbi']->selectDb($oldDb);
-
             $_message .= $pma_table->getLastMessage();
             $result = true;
             $GLOBALS['table'] = $pma_table->getName();
@@ -136,9 +165,9 @@ if (isset($_REQUEST['submitoptions'])) {
 
     $row_format = (isset($create_options['row_format']))
         ? $create_options['row_format']
-        : $pma_table->getStatusInfo('ROW_FORMAT');
+        : $pma_table->getRowFormat();
 
-    $table_alters = PMA_getTableAltersArray(
+    $table_alters = $operations->getTableAltersArray(
         $pma_table,
         $create_options['pack_keys'],
         (empty($create_options['checksum']) ? '0' : '1'),
@@ -152,13 +181,13 @@ if (isset($_REQUEST['submitoptions'])) {
 
     if (count($table_alters) > 0) {
         $sql_query      = 'ALTER TABLE '
-            . PMA\libraries\Util::backquote($GLOBALS['table']);
+            . Util::backquote($GLOBALS['table']);
         $sql_query     .= "\r\n" . implode("\r\n", $table_alters);
         $sql_query     .= ';';
         $result        .= $GLOBALS['dbi']->query($sql_query) ? true : false;
         $reread_info    = true;
         unset($table_alters);
-        $warning_messages = PMA_getWarningMessagesArray();
+        $warning_messages = $operations->getWarningMessagesArray();
     }
 
     if (isset($_REQUEST['tbl_collation'])
@@ -166,7 +195,7 @@ if (isset($_REQUEST['submitoptions'])) {
         && isset($_REQUEST['change_all_collations'])
         && ! empty($_REQUEST['change_all_collations'])
     ) {
-        PMA_changeAllColumnsCollation(
+        $operations->changeAllColumnsCollation(
             $GLOBALS['db'], $GLOBALS['table'], $_REQUEST['tbl_collation']
         );
     }
@@ -175,7 +204,7 @@ if (isset($_REQUEST['submitoptions'])) {
  * Reordering the table has been requested by the user
  */
 if (isset($_REQUEST['submitorderby']) && ! empty($_REQUEST['order_field'])) {
-    list($sql_query, $result) = PMA_getQueryAndResultForReorderingTable();
+    list($sql_query, $result) = $operations->getQueryAndResultForReorderingTable();
 } // end if
 
 /**
@@ -184,25 +213,40 @@ if (isset($_REQUEST['submitorderby']) && ! empty($_REQUEST['order_field'])) {
 if (isset($_REQUEST['submit_partition'])
     && ! empty($_REQUEST['partition_operation'])
 ) {
-    list($sql_query, $result) = PMA_getQueryAndResultForPartition();
+    list($sql_query, $result) = $operations->getQueryAndResultForPartition();
 } // end if
 
 if ($reread_info) {
     // to avoid showing the old value (for example the AUTO_INCREMENT) after
     // a change, clear the cache
     $GLOBALS['dbi']->clearTableCache();
-    include 'libraries/tbl_info.inc.php';
+    $GLOBALS['dbi']->selectDb($GLOBALS['db']);
+    $GLOBALS['showtable'] = $pma_table->getStatusInfo(null, true);
+    if ($pma_table->isView()) {
+        $tbl_is_view = true;
+        $tbl_storage_engine = __('View');
+        $show_comment = null;
+    } else {
+        $tbl_is_view = false;
+        $tbl_storage_engine = $pma_table->getStorageEngine();
+        $show_comment = $pma_table->getComment();
+    }
+    $tbl_collation = $pma_table->getCollation();
+    $table_info_num_rows = $pma_table->getNumRows();
+    $row_format = $pma_table->getRowFormat();
+    $auto_increment = $pma_table->getAutoIncrement();
+    $create_options = $pma_table->getCreateOptions();
 }
 unset($reread_info);
 
 if (isset($result) && empty($message_to_show)) {
     if (empty($_message)) {
         if (empty($sql_query)) {
-            $_message = PMA\libraries\Message::success(__('No change'));
+            $_message = Message::success(__('No change'));
         } else {
             $_message = $result
-                ? PMA\libraries\Message::success()
-                : PMA\libraries\Message::error();
+                ? Message::success()
+                : Message::error();
         }
 
         if ($response->isAjax()) {
@@ -210,19 +254,19 @@ if (isset($result) && empty($message_to_show)) {
             $response->addJSON('message', $_message);
             if (!empty($sql_query)) {
                 $response->addJSON(
-                    'sql_query', PMA\libraries\Util::getMessage(null, $sql_query)
+                    'sql_query', Util::getMessage(null, $sql_query)
                 );
             }
             exit;
         }
     } else {
         $_message = $result
-            ? PMA\libraries\Message::success($_message)
-            : PMA\libraries\Message::error($_message);
+            ? Message::success($_message)
+            : Message::error($_message);
     }
 
     if (! empty($warning_messages)) {
-        $_message = new PMA\libraries\Message;
+        $_message = new Message;
         $_message->addMessagesString($warning_messages);
         $_message->isError(true);
         if ($response->isAjax()) {
@@ -230,7 +274,7 @@ if (isset($result) && empty($message_to_show)) {
             $response->addJSON('message', $_message);
             if (!empty($sql_query)) {
                 $response->addJSON(
-                    'sql_query', PMA\libraries\Util::getMessage(null, $sql_query)
+                    'sql_query', Util::getMessage(null, $sql_query)
                 );
             }
             exit;
@@ -244,7 +288,7 @@ if (isset($result) && empty($message_to_show)) {
         );
     } else {
         $response->addHTML(
-            PMA\libraries\Util::getMessage($_message, $sql_query)
+            Util::getMessage($_message, $sql_query)
         );
     }
     unset($_message);
@@ -262,7 +306,6 @@ $columns = $GLOBALS['dbi']->getColumns($GLOBALS['db'], $GLOBALS['table']);
 /**
  * Displays the page
  */
-$response->addHTML('<div id="boxContainer" data-box-width="300">');
 
 /**
  * Order the table
@@ -272,7 +315,7 @@ $hideOrderTable = false;
 // a user-defined clustered index (PRIMARY KEY or NOT NULL UNIQUE index).
 // InnoDB always orders table rows according to such an index if one is present.
 if ($tbl_storage_engine == 'INNODB') {
-    $indexes = PMA\libraries\Index::getFromTable($GLOBALS['table'], $GLOBALS['db']);
+    $indexes = Index::getFromTable($GLOBALS['table'], $GLOBALS['db']);
     foreach ($indexes as $name => $idx) {
         if ($name == 'PRIMARY') {
             $hideOrderTable = true;
@@ -293,13 +336,13 @@ if ($tbl_storage_engine == 'INNODB') {
     }
 }
 if (! $hideOrderTable) {
-    $response->addHTML(PMA_getHtmlForOrderTheTable($columns));
+    $response->addHTML($operations->getHtmlForOrderTheTable($columns));
 }
 
 /**
  * Move table
  */
-$response->addHTML(PMA_getHtmlForMoveTable());
+$response->addHTML($operations->getHtmlForMoveTable());
 
 if (mb_strstr($show_comment, '; InnoDB free') === false) {
     if (mb_strstr($show_comment, 'InnoDB free') === false) {
@@ -323,7 +366,7 @@ if (mb_strstr($show_comment, '; InnoDB free') === false) {
 // check for version
 
 $response->addHTML(
-    PMA_getTableOptionDiv(
+    $operations->getTableOptionDiv(
         $pma_table, $comment, $tbl_collation, $tbl_storage_engine,
         $create_options['pack_keys'],
         $auto_increment,
@@ -337,13 +380,13 @@ $response->addHTML(
 /**
  * Copy table
  */
-$response->addHTML(PMA_getHtmlForCopytable());
+$response->addHTML($operations->getHtmlForCopytable());
 
 /**
  * Table maintenance
  */
 $response->addHTML(
-    PMA_getHtmlForTableMaintenance($pma_table, $url_params)
+    $operations->getHtmlForTableMaintenance($pma_table, $url_params)
 );
 
 if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
@@ -354,7 +397,7 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
         && ! (isset($db_is_system_schema) && $db_is_system_schema)
     ) {
         $this_sql_query = 'TRUNCATE TABLE '
-            . PMA\libraries\Util::backquote($GLOBALS['table']);
+            . Util::backquote($GLOBALS['table']);
         $truncate_table_url_params = array_merge(
             $url_params,
             array(
@@ -370,7 +413,7 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
     }
     if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
         $this_sql_query = 'DROP TABLE '
-            . PMA\libraries\Util::backquote($GLOBALS['table']);
+            . Util::backquote($GLOBALS['table']);
         $drop_table_url_params = array_merge(
             $url_params,
             array(
@@ -386,13 +429,13 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
                     htmlspecialchars($table)
                 ),
                 // table name is needed to avoid running
-                // PMA_relationsCleanupDatabase() on the whole db later
+                // PhpMyAdmin\RelationCleanup::database() on the whole db later
                 'table' => $GLOBALS['table'],
             )
         );
     }
     $response->addHTML(
-        PMA_getHtmlForDeleteDataOrTable(
+        $operations->getHtmlForDeleteDataOrTable(
             $truncate_table_url_params,
             $drop_table_url_params
         )
@@ -404,7 +447,7 @@ if (Partition::havePartitioning()) {
     // show the Partition maintenance section only if we detect a partition
     if (! is_null($partition_names[0])) {
         $response->addHTML(
-            PMA_getHtmlForPartitionMaintenance($partition_names, $url_params)
+            $operations->getHtmlForPartitionMaintenance($partition_names, $url_params)
         );
     } // end if
 } // end if
@@ -418,14 +461,12 @@ unset($partition_names);
 
 if ($cfgRelation['relwork'] && ! $pma_table->isEngine("INNODB")) {
     $GLOBALS['dbi']->selectDb($GLOBALS['db']);
-    $foreign = PMA_getForeigners($GLOBALS['db'], $GLOBALS['table'], '', 'internal');
+    $foreign = $relation->getForeigners($GLOBALS['db'], $GLOBALS['table'], '', 'internal');
 
     if (! empty($foreign)) {
         $response->addHTML(
-            PMA_getHtmlForReferentialIntegrityCheck($foreign, $url_params)
+            $operations->getHtmlForReferentialIntegrityCheck($foreign, $url_params)
         );
     } // end if ($foreign)
 
 } // end  if (!empty($cfg['Server']['relation']))
-
-$response->addHTML('</div>');
